@@ -64,6 +64,17 @@ ggplot(mydf, aes(x, predicted, colour = group)) +
   geom_line() +
   facet_wrap(~facet)
 
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+library(splines)
+data(women)
+
+fm1 <- lm(weight ~ bs(height, df = 5), data = women)
+dat <- ggpredict(fm1, "height")
+
+ggplot(dat, aes(x, predicted)) + 
+  geom_line() +
+  geom_point()
+
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 get_x_title(mydf)
 get_y_title(mydf)
